#!/bin/sh

# ./create-freeciv-gtk2-nsi.sh <Freeciv files directory> <version>

./create-freeciv-gtk-qt-nsi.sh $1 $2 "gtk2" "GTK+2"
